{% extends 'luxuryadmin/base.html' %}
{% load staticfiles %}
{% load thumbnail %}
{% load icanhaz %}
{% load widget_tweaks %}
{% block js %}
    {{ block.super }}
    <script src="{% static 'luxuryadmin/js/collection.js'%}"></script>
{% endblock %}
{% block admin_content %}
    {% icanhaz "productRow" %}
	<ul id="adminBreadcrumbs">
		<li><a href="/admin/collection/" title="">Admin</a></li>
		<li>Manage collection</li>
	</ul>
    {% include 'luxuryadmin/snippets/nav.html' with on='collection' %}
	<h1>Manage collection</h1>
    <div id="tableWrapper">
		<div class="extraOptions">
			<form id="productSearch" class="tableSearch" action="" method="get">
				<div class="inputPair">
					<label for="tableSearch"></label>
					<input type="text" name="tableSearch" id="tableSearch" placeholder="Start typing..." />
				</div>
			</form>
		</div>
	    <table class="products" src="{% url luxuryadmin:xhr_products %}">
            <colgroup>
				<col class="ID">
                <col class="thumbnail" />
                <col class="name" />
                <col class="actions" />
                <col class="views" />
                <col class="featured" />
                <col class="sold" />
                <col class="category" />
                <col class="delete" />
            </colgroup>
            <thead>
                <tr>
					<th><a href="#" title="" class="sortData">Ref</a></th>
                    <th>Image</th>
                    <th><a href="#" title="" class="sortData">Item</a></th>
                    <th>Actions</th>
                    <th>Views</th>
                    <th>Featured</th>
                    <th>Sold</th>
                    <th><a href="#" title="" class="sortData">Category</a></th>
                    <th>Del</th>
                </tr>
            </thead>
            <tbody>
            </tbody>
        </table>
    </div>
{% endblock %}